This is an automated email from the ASF dual-hosted git repository.

yao pushed a commit to branch branch-3.5
in repository https://gitbox.apache.org/repos/asf/spark.git


The following commit(s) were added to refs/heads/branch-3.5 by this push:
     new 7ffb4a11597 [SPARK-44875][INFRA] Fix spelling for commentator to test 
SPARK-44813
7ffb4a11597 is described below

commit 7ffb4a11597e0d2624830dc5ac044ce6c41835f8
Author: Kent Yao <y...@apache.org>
AuthorDate: Sat Aug 19 01:48:37 2023 +0800

    [SPARK-44875][INFRA] Fix spelling for commentator to test SPARK-44813
    
    ### What changes were proposed in this pull request?
    
    Fix a typo to verify SPARK-44813
    
    ### Why are the changes needed?
    
    Fix a typo and verify SPARK-44813
    
    ### Does this PR introduce _any_ user-facing change?
    
    no
    
    ### How was this patch tested?
    
    existing tests
    
    Closes #42561 from yaooqinn/SPARK-44875.
    
    Authored-by: Kent Yao <y...@apache.org>
    Signed-off-by: Kent Yao <y...@apache.org>
    (cherry picked from commit 54dd18b5e0953df37e5f0937f1f79e65db70b787)
    Signed-off-by: Kent Yao <y...@apache.org>
---
 dev/merge_spark_pr.py | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/dev/merge_spark_pr.py b/dev/merge_spark_pr.py
index 37488557fea..6af3945bc57 100755
--- a/dev/merge_spark_pr.py
+++ b/dev/merge_spark_pr.py
@@ -344,13 +344,13 @@ def resolve_jira_issue(merge_branches, comment, 
default_jira_id=""):
 def choose_jira_assignee(issue, asf_jira):
     """
     Prompt the user to choose who to assign the issue to in jira, given a list 
of candidates,
     including the original reporter and all commentors
     """
     while True:
         try:
             reporter = issue.fields.reporter
-            commentors = list(map(lambda x: x.author, 
issue.fields.comment.comments))
-            candidates = set(commentors)
+            commentators = list(map(lambda x: x.author, 
issue.fields.comment.comments))
+            candidates = set(commentators)
             candidates.add(reporter)
             candidates = list(candidates)
             print("JIRA is unassigned, choose assignee")
@@ -358,8 +358,8 @@ def choose_jira_assignee(issue, asf_jira):
                 if author.key == "apachespark":
                     continue
                 annotations = ["Reporter"] if author == reporter else []
-                if author in commentors:
-                    annotations.append("Commentor")
+                if author in commentators:
+                    annotations.append("Commentator")
                 print("[%d] %s (%s)" % (idx, author.displayName, 
",".join(annotations)))
             raw_assignee = input(
                 "Enter number of user, or userid, to assign to (blank to leave 
unassigned):"


---------------------------------------------------------------------
@@ -344,13 +344,13 @@ def resolve_jira_issue(merge_branches, comment, 
     Prompt the user to choose who to assign the issue to in jira, given a list 
of candidates,
-    including the original reporter and all commentors
+    including the original reporter and all commentators
     """
     while True:
To unsubscribe, e-mail: commits-unsubscr...@spark.apache.org
For additional commands, e-mail: commits-h...@spark.apache.org

Reply via email to